#
# spec file for package deltarpm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
%bcond_without python3
# we need to build against recent rpm, so avoid the new payload
%define _binary_payload w9.bzdio
Name:           deltarpm
Version:        3.6.3
Release:        2.12
Summary:        Tools to Create and Apply deltarpms
License:        BSD-3-Clause
Group:          System/Packages
URL:            https://github.com/rpm-software-management/deltarpm/
Source:         deltarpm-3.6.3.tar.gz
# is in upstream git
Patch0:         deltarpm-b7987f6aa4211df3df03dcfc55a00b2ce7472e0a.patch
BuildRequires:  libbz2-devel
%if %{with python2}
BuildRequires:  python2-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif
BuildRequires:  rpm-devel
BuildRequires:  xz-devel
BuildRequires:  pkgconfig(libzstd)

%description
This package contains tools to create and apply deltarpms. A deltarpm
contains the difference between an old and a new version of an RPM,
which makes it possible to recreate the new RPM from the deltarpm and
the old one. You do not need to have a copy of the old RPM, because
deltarpms can also work with installed RPMs.


%package -n python2-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Languages/Python
Provides:       python-deltarpm = %{version}-%{release}
Obsoletes:      python-deltarpm < %{version}-%{release}
Requires:       %{name} = %{version}

%description -n python2-deltarpm
Python 2 bindings for deltarpm

%package -n python3-deltarpm
Summary:        Tools to Create and Apply deltarpms
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description -n python3-deltarpm
Python 3 bindings for deltarpm

%prep
%setup -q

%build
make CC="gcc" CFLAGS="%{optflags} -DWITH_ZSTD=1" rpmdumpheader="%{_prefix}/lib/rpm/rpmdumpheader" %{?_smp_mflags} all python

%install
PYS=""
%if %{with python2}
PYS="$PYS python"
%endif
%if %{with python3}
PYS="$PYS python3"
%endif

mkdir -p %{buildroot}%{_prefix}/lib/rpm
make install DESTDIR=%{buildroot} \
    prefix="%{_prefix}" libdir="%{_libdir}" mandir="%{_mandir}" \
    rpmdumpheader="%{_prefix}/lib/rpm/rpmdumpheader" PYTHONS="$PYS"
%if %{with python2}
rm -rf %{buildroot}%{_libdir}/python/site-packages/{_deltarpmmodule.so,deltarpm.py} # Remove wrongly installed Python 2 module
mv %{buildroot}%{python_sitearch}/_deltarpm{module,}.so # Fix binary Python 2 module name
%endif
%if %{with python3}
mv %{buildroot}%{python3_sitearch}/_deltarpm{module,}.so # Fix binary Python 3 module name
%endif

%files
%doc README LICENSE.BSD
%{_bindir}/*
%{_mandir}/man8/*
%{_prefix}/lib/rpm/rpmdumpheader

%if %{with python2}
%files -n python2-deltarpm
%{python_sitearch}/deltarpm.py
%{python_sitearch}/_deltarpm.so
%endif

%if %{with python3}
%files -n python3-deltarpm
%{python3_sitearch}/deltarpm.py
%{python3_sitearch}/_deltarpm.so
%endif

%changelog
* Wed Apr 13 2022 Marcus Meissner <meissner@suse.com>
- deltarpm-b7987f6aa4211df3df03dcfc55a00b2ce7472e0a.patch: fixed
  some C bugs ( incorrect sized memset() , memcpy instead of strcpy,
  unsigned int)
* Fri Oct 29 2021 mls@suse.de
- update to deltarpm-3.6.3
  * support for threaded zstd compression
* Sat Jun 22 2019 Neal Gompa <ngompa13@gmail.com>
- Actually enable zstd compression
* Thu Jun 13 2019 mls@suse.de
- update to deltarpm-3.6.2
  * support for zstd compression
* Fri Jan  5 2018 tchvatal@suse.com
- Make python2 and python3 conditional to ensure we can build with
  python3 only
* Fri Nov 10 2017 mpluskal@suse.com
- Correct provides/obsoletes for python2 subpackage
* Tue Nov  7 2017 mpluskal@suse.com
- Build python3 bindings as well
- Rename python2 subpackage to name consistent with current python
  packaging
- Drop patch.sles8 - there does not seem to be any reason for it
* Tue Nov 24 2015 ro@suse.de
- update to version 3.6.1
  - remove upstreamed patch deltarpm-zlibcppflags.diff
  - fix off-by-one error in delta generation code (bnc#948504)
    This could lead to a segfault in rare circumstances.
  - Return error rather than crashing if we can't allocate memory
  - add newline in missing prelink error
  - do not finish applydeltarpm jobs when in the middle of a request
  - fix zlibcppflags typo
* Mon Jun 10 2013 mls@suse.de
- update to deltarpm-3.6
  * fixes failing applydeltarpm with gzip -9 compression
  * adds a couple of manpages
* Wed Jan 25 2012 saschpe@suse.de
- Package binary Python module, python-deltarpm isn't noarch any more
* Mon Jan 23 2012 saschpe@suse.de
- Run spec-cleaner
- Add python-deltarpm subpackage
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Fri Oct 15 2010 mls@suse.de
- update to current git to get support for the '-m' option,
  which limits memory consumption
* Wed Sep  9 2009 mls@suse.de
- adapt to rpm-4.7 lzma level change
* Mon Aug 24 2009 mls@suse.de
- update to version 3.5
- no changes, just patch integration
* Mon Feb 16 2009 coolo@suse.de
- adapt to xz-devel API changes (could only test makedeltarpm as
  our old deltas can not be applied anymore - resulting md5 is different)
* Wed Oct 22 2008 mls@suse.de
- add lzma and bzip2 devel packages to the buildrequires
* Thu Oct  2 2008 mls@suse.de
- fix typo in makedeltarpm [bnc#431509]
* Fri May  9 2008 mls@suse.de
- fix deltaisos with no rpms [bnc#386847]
- remove bogus write to fd3 that was added for debugging
- update drpmsync
* Sun May  4 2008 coolo@suse.de
- make lzma deltarpm available on older distris
* Tue Apr 22 2008 mls@suse.de
- add support for lzma payloads
* Mon Mar 12 2007 mls@suse.de
- update to deltarpm-3.4:
  * fixes some bugs in the prelink code
  * includes percent and fragiso patch
* Tue Sep  5 2006 mls@suse.de
- added fragiso support
- flush percent output
- updated drpmsync to current release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 mls@suse.de
- update to deltarpm-3.3 [#121866]
* Mon Sep  5 2005 mls@suse.de
- update to deltarpm-3.2
* Mon Aug 22 2005 mls@suse.de
- update to deltarpm-3.1
* Thu Aug 18 2005 cthiel@suse.de
- use $RPM_OPT_FLAGS
* Wed Aug 10 2005 mls@suse.de
- update to final deltarpm-3.0
* Thu Jun 30 2005 mls@suse.de
- update to deltarpm-3.0-beta3
* Wed Mar 16 2005 mls@suse.de
- update to deltarpm-2.2
* Wed Feb 16 2005 mls@suse.de
- update to deltarpm-2.1
* Thu Feb  3 2005 mls@suse.de
- update to deltarpm-2.0
* Fri Sep 24 2004 mls@suse.de
- always flush stdout when printing percent data
* Mon Sep 20 2004 mls@suse.de
- fix bad calloc call
* Fri Sep 10 2004 mls@suse.de
- initial version
